@@ -1,4 +1,5 @@
-"""A Scrypt-enabled password hasher for Django 1.4
+# -*- coding: utf-8 -*-
+"""A Scrypt-enabled password hasher for Django 1.4/1.5
 
 Django-Scrypt provides a Scrypt-enabled hashing class compatible
 with Django's flexible password storage system
@@ -9,7 +10,7 @@ hashers - Class used for creating Scrypt message digests
 
 Classes
 
-hashers.ScryptPasswordHasher - Scrypt hashing for Django 1.4
+hashers.ScryptPasswordHasher - Scrypt hashing for Django 1.4/1.5
 
 Typical Usage
 
@@ -28,5 +29,10 @@ PASSWORD_HASHERS = (
 'django.contrib.auth.hashers.CryptPasswordHasher',
 )
 """
-__version__ = '0.2.2'
+
+
+from __future__ import unicode_literals
+
+
+__version__ = '0.2.3'
 __all__ = ['hashers']
